<?php

switch ($messaggio) {

case "Crea Prezzi":  				$messaggio = "Criar preços"; break;
case "Inserisci i prezzi per l'anno":  		$messaggio = "Inserir os preços do ano"; break;
case "Prezzi della":  				$messaggio = "Preços da"; break;
case "tariffa":  				$messaggio = "tarifa"; break;
case "soprannominata":  			$messaggio = "denominada"; break;
case "Dal":  					$messaggio = "Do"; break;
case "al":  					$messaggio = "ao"; break;
case "inserisci i nuovi prezzi":  		$messaggio = "inserir os novos preços"; break;
case "modifica i prezzi già inseriti":  	$messaggio = "modificar os preços já inseridos"; break;
case "Costi aggiuntivi":  			$messaggio = "Custos adicionais"; break;
case "Nome del nuovo costo aggiuntivo":		$messaggio = "Nome do novo custo adicional"; break;
case "da applicare":  				$messaggio = "para aplicar"; break;
case "sempre":  				$messaggio = "sempre"; break;
case "su richiesta":  				$messaggio = "sobre pedido"; break;
case "chiedi per quanto deve essere moltiplicato":	$messaggio = "perguntar por quanto deve ser multiplicado"; break;
case "considera il costo finale come letto(i) aggiuntivo(i)":	$messaggio = "considerar o custo final como cama(s) extra(s)"; break;
case "numero di settimane":  			$messaggio = "número de semanas"; break;
case "numero di giorni":  			$messaggio = "número de dias"; break;
case "tutte":  					$messaggio = "todas"; break;
case "tutti":  					$messaggio = "todos"; break;
case "tutte meno una":  			$messaggio = "todas menos uma"; break;
case "tutti meno uno":  			$messaggio = "todos menos um"; break;
case "chiedere":  				$messaggio = "perguntar"; break;
case "considera il costo settimanale come letto(i) aggiuntivo(i)":	$messaggio = "considerar este custo semanal como cama(s) extra(s)"; break;
case "considera il costo giornaliero come letto(i) aggiuntivo(i)":	$messaggio = "considerar este custo diário como cama(s) extra(s)"; break;
case "della tariffa arrotondato a":  		$messaggio = "da tarifa arredondada a"; break;
case "considera il costo percentuale come letto(i) aggiuntivo(i)":	$messaggio = "considerar este custo percentual como cama(s) extra(s)"; break;
case "Procedi nell'inserimento del nuovo costo aggiuntivo":	$messaggio = "Progridir com a inserção do novo custo adicional"; break;
case "Caparra":  				$messaggio = "Depósito"; break;
case "arrotondata a":  				$messaggio = "arredondado a"; break;
case "Inserisci o modifica la caparra":  	$messaggio = "Inserir ou alterar o depósito"; break;
case "Vedi i prezzi già inseriti":  		$messaggio = "Visualizar os preços já inseridos"; break;
case "Torna al menù principale":  		$messaggio = "Voltar ao menu principal"; break;
case "Si deve inserire la percentuale":  	$messaggio = "Você deve inserir a percentagem"; break;
case "La caparra è stata modificata":  		$messaggio = "O depósito foi alterado"; break;
case "Si deve specificare quando applicare il costo di fine locazione":	$messaggio = "Você deve escolher quando aplicar o custo único do fim da estadia"; break;
case "Si deve inserire il nome del costo aggiuntivo":	$messaggio = "Você deve inserir o nome do custo adicional"; break;
case "Il costo aggiuntivo finale":  		$messaggio = "O custo adicional único"; break;
case "già esiste, vai alla pagina di visualizzazione periodi e tariffe per cancellarlo":	$messaggio = "já existe, vá para a página de visualusação dos períodos e as tarifas para apagá-lo"; break;
case "Per chiedere il numero da moltiplicare, il costo aggiuntivo finale non deve essere applicato automaticamente":	$messaggio = "Para perguntar por quanto deverá ser multiplicado, o custo adicional final não deve ser aplicado automaticamente"; break;
case "Si deve specificare quando applicare il costo settimanale":	$messaggio = "Você deve escolher como aplicar o custo semanal"; break;
case "Si deve specificare quando applicare il costo giornaliero":	$messaggio = "Você deve escolher como aplicar o custo diário"; break;
case "e il numero di settimane":  		$messaggio = "e o número de semanas"; break;
case "e il numero di giorni":  			$messaggio = "e o número de dias"; break;
case "Per chiedere il numero di settimane o il numero da moltiplicare, il costo aggiuntivo settimanale non deve essere applicato automaticamente":	$messaggio = "Para perguntar o número de semanas ou por quanto deverá ser multiplicado, o custo adicional semanal não deve ser aplicado automaticamente"; break;
case "Per chiedere il numero di giorni o il numero da moltiplicare, il costo aggiuntivo giornaliero non deve essere applicato automaticamente":	$messaggio = "Para perguntar o número de dias ou por quanto deverá ser multiplicado, o custo adicional diário não deve ser aplicado automaticamente"; break;
case "Il costo aggiuntivo settimanale":  	$messaggio = "O custo adicional semanal"; break;
case "Il costo aggiuntivo giornaliero":  	$messaggio = "O custo adicional diário"; break;
case "Si deve specificare quando applicare il costo percentuale":	$messaggio = "Você deve escolher como aplicar o custo percentual"; break;
case "e il valore dell'arrotondamento":		$messaggio = "e o valor do arredondamento"; break;
case "Per chiedere per quanto deve essere moltiplicato il costo aggiuntivo percentuale non deve essere applicato automaticamente":	$messaggio = "Para perguntar por quanto deverá ser multiplicado, o custo adicional percentual não deve ser aplicado automaticamente"; break;
case "Il costo aggiuntivo percentuale":		$messaggio = "O custo adicional percentual"; break;
case "è stato inserito":  			$messaggio = "foi inserido"; break;
case "Nessun dato è stato inserito":  		$messaggio = "Nenhum dado foi inserido"; break;
case "Il soprannome della":  			$messaggio = "O apelido de"; break;
case "già esiste, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo o non metterlo per inserire prezzi per nuovi periodi":	$messaggio = "já existe, use o botão \"modificar preços já inseridos\" para alterá-lo, ou não o meta para inserir preços em períodos novos"; break;
case "Il soprannome":  				$messaggio = "O apelido"; break;
case "già esiste, ne devi usare un'altro":  	$messaggio = "já existe, você deve usar outro"; break;
case "Le date del periodo numero":  		$messaggio = "As datas do período número"; break;
case "sono sbagliate":  			$messaggio = "estão erradas"; break;
case "Il periodo":  				$messaggio = "O período"; break;
case "si sovrappone ad un periodo precedente":	$messaggio = "sobrepõe outro período"; break;
case "Un prezzo nel periodo numero":  		$messaggio = "Um preço no período número"; break;
case "esiste già, usa il tasto \"modifica i prezzi già inseriti\" per cambiarlo":	$messaggio = "já existe, usar o botão \"modificar preços já inseridos\" para alterá-lo"; break;
case "è stato cambiato":  			$messaggio = "foi alterado"; break;
case "Il prezzo del periodo":  			$messaggio = "O preço do período"; break;
case "è stato inserito":  			$messaggio = "foi inserido"; break;
case "Il prezzo del periodo numero":  		$messaggio = "O preço do período número"; break;
case "è sbagliato":  				$messaggio = "está errado"; break;
case "I soldi del costo finale sono sbagliati":	$messaggio = "O valor do custo único está errado"; break;
case "I soldi del costo settimanale sono sbagliati":	$messaggio = "O valor do custo semanal está errado"; break;
case "I soldi del costo giornaliero sono sbagliati":	$messaggio = "O valor do custo diário está errado"; break;
case "I soldi del costo percentuale sono sbagliati":	$messaggio = "O valor do custo percentual está errado"; break;
case "Inserzione per settimane":  		$messaggio = "Introdução por semanas"; break;
case "Inserzione per giorni":			$messaggio = "Inserção diário"; break;
case "Inserzione per settimane":  		$messaggio = "Inserção semanal"; break;
case "Settimane dal":  				$messaggio = "Semanal de"; break;
case "Dom/Lun":  				$messaggio = "Dom/Seg"; break;
case "Lun/Mar":  				$messaggio = "Seg/Ter"; break;
case "Mar/Mer":  				$messaggio = "Ter/Qua"; break;
case "Mer/Gio":  				$messaggio = "Qua/Qui"; break;
case "Gio/Ven":  				$messaggio = "Qui/Sex"; break;
case "Ven/Sab":  				$messaggio = "Sex/Sáb"; break;
case "Sab/Dom":  				$messaggio = "Sáb/Dom"; break;
case "inserisci o modifica i prezzi":  		$messaggio = "Inserir ou alterar os preços"; break;
case "Le date sono sbagliate":  		$messaggio = "As datas estão erradas"; break;
case "Il formato dei soldi è sbagliato":  	$messaggio = "O formato do dinherio está errado"; break;
case "I prezzi per le settimane dal":  		$messaggio = "Os preços para as semanas do"; break;
case "della <b>tariffa":  			$messaggio = "da <b>tarifa"; break;
case "sono stati inseriti":  			$messaggio = "foram inseridos"; break;
case "si":  					$messaggio = "sim"; break;
case "no":  					$messaggio = "não"; break;
case "assegnato automaticamente con tariffe":  	$messaggio = "atribuído automaticamente com as tarifas"; break;
case "nessuna":  				$messaggio = "nenhuma"; break;
case "scegliere":  				$messaggio = "escolher"; break;
case "mostrare nella pagina di inserzione prenotazioni":	$messaggio = "mostrar na página de inserção de reservas"; break;
case "Torna indietro":  			$messaggio = "Voltar"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>finale</b>":	$messaggio = "Escolher as tarifas às quais aplicar automaticamente o custo adicional <b>único</b>"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>settimanale</b>":	$messaggio = "Escolher as tarifas às quais aplicar automaticamente o custo adicional <b>semanal</b>"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>giornaliero</b>":	$messaggio = "Escolher as tarifas às quais aplicar automaticamente o custo adicional <b>diário</b>"; break;
case "Scegli le tariffe a cui verrà applicato automatiamente il costo <b>percentuale</b>":	$messaggio = "Escolher as tarifas às quais aplicar automaticamente o custo adicional <b>percentual</b>"; break;
case "Continua":  				$messaggio = "Continar"; break;
case "Tipo di costo aggiuntivo":  		$messaggio = "Tipo de custo adicional"; break;
case "unico":  					$messaggio = "único"; break;
case "settimanale":  				$messaggio = "semanal"; break;
case "giornaliero":  				$messaggio = "diário"; break;
case "il prezzo totale":  			$messaggio = "preço total"; break;
case "la caparra":  				$messaggio = "o depósito"; break;
case "totale meno caparra":  			$messaggio = "total menos depósito"; break;
case "minimo":  				$messaggio = "mínimo"; break;
case "massimo":  				$messaggio = "máximo"; break;
case "esattamente":  				$messaggio = "exatamente"; break;
case "settimane":  				$messaggio = "semanas"; break;
case "giorni":  				$messaggio = "dias"; break;
case "Se possibile":  				$messaggio = "Se possível"; break;
case "Sempre":  				$messaggio = "Sempre"; break;
case "Associare a specifiche settimane della prenotazione":	$messaggio = "Associar a semanas específicas da reserva"; break;
case "Associare a specifici giorni della prenotazione":	$messaggio = "Associar a dias específicos da reserva"; break;
case "Tutte":  					$messaggio = "Todas"; break;
case "Tutti":  					$messaggio = "Todos"; break;
case "Tutte meno":  				$messaggio = "Todas menos"; break;
case "Tutti meno":  				$messaggio = "Todos menos"; break;
case "la prima":  				$messaggio = "a primeira"; break;
case "il primo":  				$messaggio = "o primeiro"; break;
case "l'ultima":  				$messaggio = "a última"; break;
case "l'ultimo":  				$messaggio = "o último"; break;
case "Chiedere":  				$messaggio = "Perguntar"; break;
case "settimane sì":  				$messaggio = "semanas sim"; break;
case "giorni sì":  				$messaggio = "dias sim"; break;
case "settimane no":  				$messaggio = "semanas não"; break;
case "giorni no":  				$messaggio = "dias sim"; break;
case "e":  					$messaggio = "e"; break;
case "Giorni della settimana selezionati":  	$messaggio = "Dias da semana escolhidos"; break;
case "Lunedì":  				$messaggio = "Segunda-feira"; break;
case "Martedì":  				$messaggio = "Terça-feira"; break;
case "Mercoledì":  				$messaggio = "Quarta-feira"; break;
case "Giovedì":  				$messaggio = "Quinta-feira"; break;
case "Venerdì":  				$messaggio = "Sexta-feira"; break;
case "Sabato":  				$messaggio = "Sábado"; break;
case "Domenica":  				$messaggio = "Domingo"; break;
case "Moltiplicare il costo per":  		$messaggio = "Multiplicar o custo por"; break;
case "Uno":  					$messaggio = "Um"; break;
case "Chiedere":  				$messaggio = "Perguntar"; break;
case "Numero di persone":  			$messaggio = "Número de pessoas"; break;
case "Numero di persone totale":  		$messaggio = "Número total de pessoas"; break;
case "escluse quelle dei costi con letti aggiuntivi":	$messaggio = "excluíndo aqueles de custos com camas extras"; break;
case "Periodi in cui è permesso inserire il costo":	$messaggio = "Períodos nos quais é permitido inserir o custo"; break;
case "In tutti":  				$messaggio = "Em todos"; break;
case "Solo nei periodi selezionati":  		$messaggio = "Apenas nos períodos escolhidos"; break;
case "dal":  					$messaggio = "de"; break;
case "Elimina un periodo":  			$messaggio = "Apagar um período"; break;
case "Aggiungi un periodo":  			$messaggio = "Acrescentar um período"; break;
case "se tutte le settimane della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "se todas as semanas da reserva estão nos períodos escolhidos"; break;
case "se tutti i giorni della prenotazione sono all'interno dei periodi selezionati":	$messaggio = "se todos os dias da reserva estão nos períodos escolhidos"; break;
case "se anche una sola settimana della prenotazione è all'interno dei periodi selezionati":	$messaggio = "se mesmo apenas uma semana da reserva estiver nos períodos escolhidos"; break;
case "se anche un solo giorno della prenotazione è all'interno dei periodi selezionati":	$messaggio = "se mesmo apenas um dia da reserva estiver nos períodos escolhidos"; break;
case "applicare il costo solo in settimane permesse all'interno della prenotazione":	$messaggio = "aplicar o custo apenas a semanas permitidas na reserva"; break;
case "applicare il costo solo in giorni permessi all'interno della prenotazione":	$messaggio = "aplicar o custo apenas a dias permitidos na reserva"; break;
case "Caratteristiche del costo da mantenere quando si modifica una prenotazione":	$messaggio = "Carateríticas do custo para manter quando uma reserva será alterada"; break;
case "Valore percentuale":  			$messaggio = "Valor percentual"; break;
case "e settimane associate":  			$messaggio = "e semanas associadas"; break;
case "e giorni associati":  			$messaggio = "e dias associados"; break;
case "Assegnazione settimane":  		$messaggio = "Atribuição semanal"; break;
case "Assegnazione giorni":  			$messaggio = "Atribuição diária"; break;
case "Numero per cui viene moltiplicato":  	$messaggio = "Número pelo qual vai ser multiplicado"; break;
case "Periodi permessi":  			$messaggio = "Períodos concedidos"; break;
case "Associazione alle tariffe":  		$messaggio = "Associação às tarifas"; break;
case "Mostrare nella pagina di inserimento delle prenotazioni":	$messaggio = "Mostrar na página de inserção de reservas"; break;
case "Si":  					$messaggio = "Sim"; break;
case "No":  					$messaggio = "Não"; break;
case "Considerare il costo come letto/i aggiuntivo/i":	$messaggio = "Considerar este custo adicional como cama(s) extra(s)"; break;
case "Limitarne il numero che è possibile avere contemporaneamente in uno stesso periodo":	$messaggio = "Limitar o número que é possível ter contemporaneamente no mesmo período"; break;
case "Valore del costo":  			$messaggio = "Valor do custo"; break;
case "fisso di":  				$messaggio = "fixo de"; break;
case "percentuale su":  			$messaggio = "percentagem sobre"; break;
case "la tariffa":  				$messaggio = "a tarifa"; break;
case "indietro":  				$messaggio = "voltar"; break;
case "avanti":  				$messaggio = "seguir"; break;
case "del":  					$messaggio = "do"; break;
case "arrotondato a":  				$messaggio = "arredondado a"; break;
case "Errore nei valori inseriti":  		$messaggio = "Erro nos valores inseridos"; break;
case "Assegnare automaticamente con le tariffe selezionate":	$messaggio = "Atribuir automaticamente com as tarifas escolhidas"; break;
case "Tariffe":  				$messaggio = "Tarifas"; break;
case "Il costo aggiuntivo":  			$messaggio = "O custo adicional"; break;
case "OK":  					$messaggio = "OK"; break;
case "Le settimane a cui applicare il costo":	$messaggio = "As semanas às quais aplicar o custo"; break;
case "I giorni a cui applicare il costo":	$messaggio = "Os dias aos quais aplicar o custo"; break;
case "uno":  					$messaggio = "um"; break;
case "NO":  					$messaggio = "NÃO"; break;
case "SI":  					$messaggio = "SIM"; break;
case "Costo aggiuntivo già esistente":  	$messaggio = "O custo adicional já existe"; break;
case "Tariffe incompatibili con il costo":  	$messaggio = "Tarifas incompatíveis com o custo"; break;
case "Tariffe incompatibili":  			$messaggio = "Tarifas incompatíveis"; break;
case "i prezzi della":  			$messaggio = "os preços na"; break;
case "dalla":  					$messaggio = "com base da"; break;
case "aggiungendo":  				$messaggio = "acrescentando"; break;
case "I prezzi della tariffa selezionata sono stati importati":	$messaggio = "Os preços da tarifa escolhida foram aplicados"; break;
case "importa":  				$messaggio = "importar"; break;
case "se selezionato mantenere anche":  	$messaggio = "se escolhido manter também"; break;
case "Quando possibile assegna automaticamente se mancano":	$messaggio = "Se possível atribuir automaticamente se faltam"; break;
case "meno di":  				$messaggio = "menos do que"; break;
case "più di":  				$messaggio = "mais do que"; break;
case "giorni dalla data iniziale della prenotazione quando viene inserita":	$messaggio = "dias até à data inicial da reserva quando é inserida"; break;
case "Quando possibile assegna automaticamente se si inseriscono":	$messaggio = "Se possível atribuir automaticamente se inserir"; break;
case "o più prenotazioni contemporaneamente":	$messaggio = "ou mais reservas simultaneamente"; break;
case "Modifica il costo":  			$messaggio = "Modificar o custo"; break;
case "Inserisci un nuovo costo aggiuntivo chiamato":	$messaggio = "Inserir um novo custo adicional chamado"; break;
case "importando le caratteristiche da":	$messaggio = "importando as caraterísticas de"; break;
case "Sempre in periodi permessi":  		$messaggio = "Sempre em períodos permitidos"; break;
case "Prezzo dell'intera settimana":  		$messaggio = "Preço da inteira semana"; break;
case "Prezzi dei giorni":  			$messaggio = "Preços dos dias"; break;
case "tra":  					$messaggio = "entre"; break;
case "Beni dell'inventario da eliminare quando si inserisce il costo":	$messaggio = "Bens do inventário para excluir quando o custo e inserido"; break;
case "Nessuno":  				$messaggio = "Nenhum"; break;
case "Beni selezionati":  			$messaggio = "Bens escolhidos"; break;
case "Aggiungi un bene":  			$messaggio = "Acrescentar um bem"; break;
case "Elimina un bene":  			$messaggio = "Apagar um bem"; break;
case "elimina i beni dall'inventario del magazzino":	$messaggio = "apagar os bens do inventário do armazém"; break;
case "Beni dell'inventario da eliminare":  	$messaggio = "Bens de inventário para apagar"; break;
case "Mostrare raggruppato con costi simili della stessa categoria in inserimento":	$messaggio = "Mostrar agrupado com custos semelhantes na mesma categoria em inclusão"; break;
case "Il tipo di applicazione della":  		$messaggio = "O tipo de aplicação da"; break;
case "per persona":  				$messaggio = "por pessoa"; break;
case "per settimana":  				$messaggio = "por semana"; break;
case "per giorno":  				$messaggio = "por dia"; break;
case "La caparra è errata":  			$messaggio = "O depósito está errado"; break;
case "è":  					$messaggio = "é"; break;
case "il":  					$messaggio = "o"; break;
case "Commissioni":  				$messaggio = "Comissões"; break;
case "sono":  					$messaggio = "são"; break;
case "Inserisci o modifica le commissioni":  	$messaggio = "Inserir ou alterar as comissões"; break;
case "Tasse":  					$messaggio = "Taxas"; break;
case "Tasse applicate su":  			$messaggio = "Taxas aplicadas em"; break;
case "della tariffa":  				$messaggio = "da tarifa"; break;
case "Inserisci o modifica le tasse":  		$messaggio = "Inserir ou alterar as taxas"; break;
case "Le commissioni sono state modificate":  	$messaggio = "As comissões foram alteradas"; break;
case "Le commissioni sono errate":  		$messaggio = "As comissões estão erradas"; break;
case "Le tasse sono state modificate":  	$messaggio = "As taxas foram alteradas"; break;
case "Le tasse sono errate":  			$messaggio = "As comissões estão erradas"; break;
case "tutti i prezzi delle tariffe si intendono con tasse già incluse":	$messaggio = "Todos as tarifas já estão com todas as taxas incluídos"; break;
case "Inserisci o modifica le commissioni normali":  	$messaggio = "Adicionar ou alterar comissões normais"; break;
case "Inserisci o modifica le commissioni in questo periodo":  	$messaggio = "Adicionar ou alterar comissões neste período"; break;
case "Sulla":  					$messaggio = "Na"; break;
case "al giorno":  				$messaggio = "por dia"; break;
case "alla settimana":  			$messaggio = "por semana"; break;
case "il valore del costo si intente con tasse già incluse":	$messaggio = "o valor do custo já está com todas as taxas incluído"; break;
case "Categoria":  				$messaggio = "Categoria"; break;
case "il prezzo della tariffa per i primi":  	$messaggio = "o preço da tarifa pelo primeiro"; break;
case "il prezzo della tariffa per le prime":  	$messaggio = "o preço da tarifa pela primeira"; break;
case "della":  					$messaggio = "da"; break;
case "tariffa + sconto":  			$messaggio = "tarifa + desconto"; break;
case "tariffa + sconto + costi agg.":  		$messaggio = "tarifa + desconto + custos adicionais"; break;
case "della tar.":  				$messaggio = "da tarifa"; break;
case "di t.+s.":  				$messaggio = "da tarifa + desconto"; break;
case "di t.+s.+c.a.":  				$messaggio = "da tarifa + desconto + comissão + custos adicionais"; break;
case "Nome della":  				$messaggio = "Nome da"; break;
case "Cambia":  				$messaggio = "Alterar"; break;
case "prezzo per settimana":  			$messaggio = "preço por semana"; break;
case "prezzo per giorno":  			$messaggio = "preço por dia"; break;
case "prezzo per persona per settimana":  	$messaggio = "preço por pessoa e semana"; break;
case "prezzo per persona per giorno":  		$messaggio = "preço por pessoa e dia"; break;
case "p":  					$messaggio = "pess."; break;
case "parte fissa della tariffa":  		$messaggio = "parte fixa da tarifa"; break;
case "parte per una persona della tariffa":  	$messaggio = "parte por pessoa da tarifa"; break;
case "Numero massimo":  			$messaggio = "Número máximo"; break;
case "0 se illimitato":  			$messaggio = "0 (zero) se ilimitada"; break;
case "meno":  					$messaggio = "menos"; break;
case "il costo viene moltiplicato per zero se la somma è negativa":	$messaggio = "o custo é multiplicado por zero se a soma é negativa"; break;
case "Combina con altri costi":			$messaggio = "Combinar com outros custos"; break;
case "i costi combinabili vengono mostrati tutti assieme con il nome della categoria ed ognuno è inserito se possibile":	$messaggio = "os custos combinados são mostradas em conjunto com o nome de cada categoria e cada qual está sendo inserido se possível"; break;
case "opzionale":  				$messaggio = "opcional"; break;
case "Costi combinati":  			$messaggio = "Custos combinados"; break;
case "Inserimento rapido di un nuovo costo aggiuntivo per":	$messaggio = "Entrada rápida de um novo custo adicional para"; break;
case "permanenza minima":  			$messaggio = "estadia mínima"; break;
case "numero di neonati":  			$messaggio = "número de bebés"; break;
case "letto aggiuntivo":  			$messaggio = "cama extra"; break;
case "offerta speciale":  			$messaggio = "oferta especial"; break;
case "inserisci":  				$messaggio = "adicionar"; break;
case "Inserisci il costo aggiuntivo":  		$messaggio = "Inserir o custo adicional"; break;
case "Numero minimo di giorni":  		$messaggio = "Número mínimo de dias"; break;
case "Applicato alle tariffe":  		$messaggio = "Aplicado às tarifas"; break;
case "Periodi in cui viene applicato il costo":	$messaggio = "Períodos em que será aplicado o custo"; break;
case "Valore per ogni neonato":  		$messaggio = "Valor por bebé"; break;
case "del prezzo di una persona":  		$messaggio = "do preço de uma pessoa"; break;
case "solo per tariffe con prezzi a persona":  	$messaggio = "apenas por tarifas com preços por pessoa"; break;
case "con questo costo il numero di neonati non è incluso nel numero di persone":	$messaggio = "com este custo, o número de bebés não está incluído no número de hospedes"; break;
case "Valore del letto aggiuntivo":  		$messaggio = "Valor da cama extra"; break;
case "Valore dello sconto":  			$messaggio = "Valor do desconto"; break;
case "del prezzo totale":  			$messaggio = "do preço total"; break;
case "Se la prenotazione ha una durata di":	$messaggio = "Se a reserva tem uma duração de"; break;
case "o più giorni":  				$messaggio = "dias ou mais"; break;
case "Se":  					$messaggio = "Se"; break;
case "Se si inseriscono":  			$messaggio = "Se se inserirem"; break;
case "Importa ora":  				$messaggio = "Importar agora"; break;
case "Importa sempre":  			$messaggio = "Importar sempre"; break;
case "cancella":  				$messaggio = "apagar"; break;
case "L'importatazione dei prezzi è stata cancellata":	$messaggio = "A aplicação dos preços foi apagada"; break;
case "al prezzo fisso":  			$messaggio = "com plano de preço fixo"; break;
case "al prezzo per persona":  			$messaggio = "com plano preço por pessoa"; break;
case "ad entrambi i prezzi":  			$messaggio = "com ambos os planos de preços"; break;
case "La tariffa":  				$messaggio = "A tarifa"; break;
case "esporta i prezzi ad altre tariffe, non può importare i prezzi in modo permanente":	$messaggio = "aplica preços a outras tarifas. Não é possível importar os preços em modo permanente"; break;
case "tutte le tariffe":  			$messaggio = "todas as tarifas"; break;
case "considerare l'intero costo come tasse":  	$messaggio = "considerar o inteiro custo como taxas"; break;
case "Escludere questo costo dal totale per altri costi percentuali":	$messaggio = "Excluir este custo do total por outros custos porcentuais"; break;
case "in tutti i periodi in modo predefinito":	$messaggio = "em todos os períodos em modo padrão"; break;
case "importa i prezzi da altre tariffe, non può esportare i prezzi":	$messaggio = "importar os preços de outras tarifas (não podera exportar estes preços)"; break;
case "importa già i prezzi da altre tariffe in questi periodi, non può importare altri prezzi":	$messaggio = "já está importando preços de outras tarifas, portanto não pode importar estes preços"; break;
case "modifica":  				$messaggio = "modificar"; break;
case "In modo predefinito importa":  		$messaggio = "Importar por padrão"; break;
case "i prezzi di alcuni periodi <em>non sono stati inseriti</em> perchè importati da altre tariffe":	$messaggio = "os preços de alguns períodos <em>não foram inseridos</em> porque eles foram importados por outras tarifas já"; break;
case "limite non considerato per le persone aggiuntive nelle interconnessioni":	$messaggio = "limite não considerado para pessoas adicionais nas interligações"; break;
case "Seleziona adesso questo costo anche per tutti gli utenti che non hanno privilegi per usare tutti i costi":	$messaggio = "Agora selecione esse custo também para todos os usuários que não têm privilégios para usar todos os custos"; break;
case "Aggiungi adesso questo costo a tutte le pagine create per il sito web":	$messaggio = "Adicione este custo agora à todas as páginas web criadas"; break;
case "Se si moltiplica per il numero di persone":	$messaggio = "Multiplicando-se com o númer de pessoas"; break;
case "escludi":  				$messaggio = "exclua"; break;
case "includi solo":  				$messaggio = "incluem apenas"; break;
case "questi tipi":  				$messaggio = "estes tipos"; break;
case "Mostrare come tipo di persona":  		$messaggio = "Mostrar como um tipo de pessoa"; break;
case "Applicare la percentuale del tipo di persona al prezzo del costo":	$messaggio = "Aplicar a percentagem do tipo de pessoa ao preço do custo"; break;
case "Neonati (0-23 mesi)":  			$messaggio = "Bebês (0-23 meses)"; break;
case "tariffe con":  				$messaggio = "tarifas com"; break;
case "a":  					$messaggio = "ao"; break;
case "La caparra normale per":  		$messaggio = "The normal deposit for"; break;
case "Le commissioni normali su":  		$messaggio = "The normal commissions on"; break;
case "per persona nullo":  			$messaggio = "per person zero"; break;
case "fisso nullo":  				$messaggio = "fixed zero"; break;
case "da per persona":  			$messaggio = "from per person"; break;
case "più fisso":  				$messaggio = "from fixed"; break;
case "dal fisso":  				$messaggio = "plus fixed"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>